An open port as seen by the platform layer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Stream<
Uint8List> -
Incoming bytes. Emits a HardwareException error before closing when the
device goes away, and closes after close.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Releases the port. Safe to call more than once.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSignals(
{bool? dtr, bool? rts}) → Future< void> -
Sets modem control lines.
nullleaves a line unchanged. -
toString(
) → String -
A string representation of this object.
inherited
-
write(
Uint8List data, Duration timeout) → Future< void> -
Writes all of
data, failing with OperationTimeout aftertimeout.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited