input property
Incoming bytes. Emits a HardwareException error before closing when the device goes away, and closes after close.
Implementation
Stream<Uint8List> get input;
Incoming bytes. Emits a HardwareException error before closing when the device goes away, and closes after close.
Stream<Uint8List> get input;