requestAccess abstract method
Requests access, which may show system dialogs.
On the web this must be called from a user gesture such as a tap.
Implementation
Future<AccessReport> requestAccess([DeviceHandle? device]);
Requests access, which may show system dialogs.
On the web this must be called from a user gesture such as a tap.
Future<AccessReport> requestAccess([DeviceHandle? device]);