request abstract method
Shows the system port chooser, if the platform has one.
Returns the chosen port, or null when the user cancels.
Implementation
Future<DeviceHandle?> request(List<DeviceFilter> filters);
Shows the system port chooser, if the platform has one.
Returns the chosen port, or null when the user cancels.
Future<DeviceHandle?> request(List<DeviceFilter> filters);